# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grafeas/grafeas_v1/proto/grafeas.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from grafeas.grafeas_v1.proto import (
    attestation_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_attestation__pb2,
)
from grafeas.grafeas_v1.proto import (
    build_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_build__pb2,
)
from grafeas.grafeas_v1.proto import (
    common_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2,
)
from grafeas.grafeas_v1.proto import (
    deployment_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_deployment__pb2,
)
from grafeas.grafeas_v1.proto import (
    discovery_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_discovery__pb2,
)
from grafeas.grafeas_v1.proto import (
    image_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_image__pb2,
)
from grafeas.grafeas_v1.proto import (
    package_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2,
)
from grafeas.grafeas_v1.proto import (
    upgrade_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_upgrade__pb2,
)
from grafeas.grafeas_v1.proto import (
    vulnerability_pb2 as grafeas_dot_grafeas__v1_dot_proto_dot_vulnerability__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="grafeas/grafeas_v1/proto/grafeas.proto",
    package="grafeas.v1",
    syntax="proto3",
    serialized_options=b"\n\rio.grafeas.v1P\001ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\242\002\003GRA\352A(\n\022grafeas.io/Project\022\022projects/{project}",
    create_key=_descriptor._internal_create_key,
    serialized_pb=b'\n&grafeas/grafeas_v1/proto/grafeas.proto\x12\ngrafeas.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a*grafeas/grafeas_v1/proto/attestation.proto\x1a$grafeas/grafeas_v1/proto/build.proto\x1a%grafeas/grafeas_v1/proto/common.proto\x1a)grafeas/grafeas_v1/proto/deployment.proto\x1a(grafeas/grafeas_v1/proto/discovery.proto\x1a$grafeas/grafeas_v1/proto/image.proto\x1a&grafeas/grafeas_v1/proto/package.proto\x1a&grafeas/grafeas_v1/proto/upgrade.proto\x1a,grafeas/grafeas_v1/proto/vulnerability.proto"\xd8\x05\n\nOccurrence\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cresource_uri\x18\x02 \x01(\t\x12\x11\n\tnote_name\x18\x03 \x01(\t\x12"\n\x04kind\x18\x04 \x01(\x0e\x32\x14.grafeas.v1.NoteKind\x12\x13\n\x0bremediation\x18\x05 \x01(\t\x12/\n\x0b\x63reate_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\rvulnerability\x18\x08 \x01(\x0b\x32#.grafeas.v1.VulnerabilityOccurrenceH\x00\x12,\n\x05\x62uild\x18\t \x01(\x0b\x32\x1b.grafeas.v1.BuildOccurrenceH\x00\x12,\n\x05image\x18\n \x01(\x0b\x32\x1b.grafeas.v1.ImageOccurrenceH\x00\x12\x30\n\x07package\x18\x0b \x01(\x0b\x32\x1d.grafeas.v1.PackageOccurrenceH\x00\x12\x36\n\ndeployment\x18\x0c \x01(\x0b\x32 .grafeas.v1.DeploymentOccurrenceH\x00\x12\x34\n\tdiscovery\x18\r \x01(\x0b\x32\x1f.grafeas.v1.DiscoveryOccurrenceH\x00\x12\x38\n\x0b\x61ttestation\x18\x0e \x01(\x0b\x32!.grafeas.v1.AttestationOccurrenceH\x00\x12\x30\n\x07upgrade\x18\x0f \x01(\x0b\x32\x1d.grafeas.v1.UpgradeOccurrenceH\x00:G\xea\x41\x44\n\x15grafeas.io/Occurrence\x12+projects/{project}/occurrences/{occurrence}B\t\n\x07\x64\x65tails"\x82\x06\n\x04Note\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x19\n\x11short_description\x18\x02 \x01(\t\x12\x18\n\x10long_description\x18\x03 \x01(\t\x12"\n\x04kind\x18\x04 \x01(\x0e\x32\x14.grafeas.v1.NoteKind\x12+\n\x0brelated_url\x18\x05 \x03(\x0b\x32\x16.grafeas.v1.RelatedUrl\x12\x33\n\x0f\x65xpiration_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x63reate_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bupdate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x12related_note_names\x18\t \x03(\t\x12\x36\n\rvulnerability\x18\n \x01(\x0b\x32\x1d.grafeas.v1.VulnerabilityNoteH\x00\x12&\n\x05\x62uild\x18\x0b \x01(\x0b\x32\x15.grafeas.v1.BuildNoteH\x00\x12&\n\x05image\x18\x0c \x01(\x0b\x32\x15.grafeas.v1.ImageNoteH\x00\x12*\n\x07package\x18\r \x01(\x0b\x32\x17.grafeas.v1.PackageNoteH\x00\x12\x30\n\ndeployment\x18\x0e \x01(\x0b\x32\x1a.grafeas.v1.DeploymentNoteH\x00\x12.\n\tdiscovery\x18\x0f \x01(\x0b\x32\x19.grafeas.v1.DiscoveryNoteH\x00\x12\x32\n\x0b\x61ttestation\x18\x10 \x01(\x0b\x32\x1b.grafeas.v1.AttestationNoteH\x00\x12*\n\x07upgrade\x18\x11 \x01(\x0b\x32\x17.grafeas.v1.UpgradeNoteH\x00:5\xea\x41\x32\n\x0fgrafeas.io/Note\x12\x1fprojects/{project}/notes/{note}B\x06\n\x04type"C\n\x14GetOccurrenceRequest\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe0\x41\x02\xfa\x41\x17\n\x15grafeas.io/Occurrence"{\n\x16ListOccurrencesRequest\x12*\n\x06parent\x18\x01 \x01(\tB\x1a\xe0\x41\x02\xfa\x41\x14\n\x12grafeas.io/Project\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t"_\n\x17ListOccurrencesResponse\x12+\n\x0boccurrences\x18\x01 \x03(\x0b\x32\x16.grafeas.v1.Occurrence\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"F\n\x17\x44\x65leteOccurrenceRequest\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe0\x41\x02\xfa\x41\x17\n\x15grafeas.io/Occurrence"v\n\x17\x43reateOccurrenceRequest\x12*\n\x06parent\x18\x01 \x01(\tB\x1a\xe0\x41\x02\xfa\x41\x14\n\x12grafeas.io/Project\x12/\n\noccurrence\x18\x02 \x01(\x0b\x32\x16.grafeas.v1.OccurrenceB\x03\xe0\x41\x02"\xa8\x01\n\x17UpdateOccurrenceRequest\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe0\x41\x02\xfa\x41\x17\n\x15grafeas.io/Occurrence\x12/\n\noccurrence\x18\x02 \x01(\x0b\x32\x16.grafeas.v1.OccurrenceB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"7\n\x0eGetNoteRequest\x12%\n\x04name\x18\x01 \x01(\tB\x17\xe0\x41\x02\xfa\x41\x11\n\x0fgrafeas.io/Note"G\n\x18GetOccurrenceNoteRequest\x12+\n\x04name\x18\x01 \x01(\tB\x1d\xe0\x41\x02\xfa\x41\x17\n\x15grafeas.io/Occurrence"u\n\x10ListNotesRequest\x12*\n\x06parent\x18\x01 \x01(\tB\x1a\xe0\x41\x02\xfa\x41\x14\n\x12grafeas.io/Project\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t"M\n\x11ListNotesResponse\x12\x1f\n\x05notes\x18\x01 \x03(\x0b\x32\x10.grafeas.v1.Note\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t":\n\x11\x44\x65leteNoteRequest\x12%\n\x04name\x18\x01 \x01(\tB\x17\xe0\x41\x02\xfa\x41\x11\n\x0fgrafeas.io/Note"z\n\x11\x43reateNoteRequest\x12*\n\x06parent\x18\x01 \x01(\tB\x1a\xe0\x41\x02\xfa\x41\x14\n\x12grafeas.io/Project\x12\x14\n\x07note_id\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12#\n\x04note\x18\x03 \x01(\x0b\x32\x10.grafeas.v1.NoteB\x03\xe0\x41\x02"\x90\x01\n\x11UpdateNoteRequest\x12%\n\x04name\x18\x01 \x01(\tB\x17\xe0\x41\x02\xfa\x41\x11\n\x0fgrafeas.io/Note\x12#\n\x04note\x18\x02 \x01(\x0b\x32\x10.grafeas.v1.NoteB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"z\n\x1aListNoteOccurrencesRequest\x12%\n\x04name\x18\x01 \x01(\tB\x17\xe0\x41\x02\xfa\x41\x11\n\x0fgrafeas.io/Note\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t"c\n\x1bListNoteOccurrencesResponse\x12+\n\x0boccurrences\x18\x01 \x03(\x0b\x32\x16.grafeas.v1.Occurrence\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"\xc9\x01\n\x17\x42\x61tchCreateNotesRequest\x12*\n\x06parent\x18\x01 \x01(\tB\x1a\xe0\x41\x02\xfa\x41\x14\n\x12grafeas.io/Project\x12\x42\n\x05notes\x18\x02 \x03(\x0b\x32..grafeas.v1.BatchCreateNotesRequest.NotesEntryB\x03\xe0\x41\x02\x1a>\n\nNotesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.grafeas.v1.Note:\x02\x38\x01";\n\x18\x42\x61tchCreateNotesResponse\x12\x1f\n\x05notes\x18\x01 \x03(\x0b\x32\x10.grafeas.v1.Note"}\n\x1d\x42\x61tchCreateOccurrencesRequest\x12*\n\x06parent\x18\x01 \x01(\tB\x1a\xe0\x41\x02\xfa\x41\x14\n\x12grafeas.io/Project\x12\x30\n\x0boccurrences\x18\x02 \x03(\x0b\x32\x16.grafeas.v1.OccurrenceB\x03\xe0\x41\x02"M\n\x1e\x42\x61tchCreateOccurrencesResponse\x12+\n\x0boccurrences\x18\x01 \x03(\x0b\x32\x16.grafeas.v1.Occurrence2\x92\x10\n\x07Grafeas\x12}\n\rGetOccurrence\x12 .grafeas.v1.GetOccurrenceRequest\x1a\x16.grafeas.v1.Occurrence"2\x82\xd3\xe4\x93\x02%\x12#/v1/{name=projects/*/occurrences/*}\xda\x41\x04name\x12\x97\x01\n\x0fListOccurrences\x12".grafeas.v1.ListOccurrencesRequest\x1a#.grafeas.v1.ListOccurrencesResponse";\x82\xd3\xe4\x93\x02%\x12#/v1/{parent=projects/*}/occurrences\xda\x41\rparent,filter\x12\x83\x01\n\x10\x44\x65leteOccurrence\x12#.grafeas.v1.DeleteOccurrenceRequest\x1a\x16.google.protobuf.Empty"2\x82\xd3\xe4\x93\x02%*#/v1/{name=projects/*/occurrences/*}\xda\x41\x04name\x12\x9c\x01\n\x10\x43reateOccurrence\x12#.grafeas.v1.CreateOccurrenceRequest\x1a\x16.grafeas.v1.Occurrence"K\x82\xd3\xe4\x93\x02\x31"#/v1/{parent=projects/*}/occurrences:\noccurrence\xda\x41\x11parent,occurrence\x12\xc0\x01\n\x16\x42\x61tchCreateOccurrences\x12).grafeas.v1.BatchCreateOccurrencesRequest\x1a*.grafeas.v1.BatchCreateOccurrencesResponse"O\x82\xd3\xe4\x93\x02\x34"//v1/{parent=projects/*}/occurrences:batchCreate:\x01*\xda\x41\x12parent,occurrences\x12\xa6\x01\n\x10UpdateOccurrence\x12#.grafeas.v1.UpdateOccurrenceRequest\x1a\x16.grafeas.v1.Occurrence"U\x82\xd3\xe4\x93\x02\x31\x32#/v1/{name=projects/*/occurrences/*}:\noccurrence\xda\x41\x1bname,occurrence,update_mask\x12\x85\x01\n\x11GetOccurrenceNote\x12$.grafeas.v1.GetOccurrenceNoteRequest\x1a\x10.grafeas.v1.Note"8\x82\xd3\xe4\x93\x02+\x12)/v1/{name=projects/*/occurrences/*}/notes\xda\x41\x04name\x12\x65\n\x07GetNote\x12\x1a.grafeas.v1.GetNoteRequest\x1a\x10.grafeas.v1.Note",\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{name=projects/*/notes/*}\xda\x41\x04name\x12\x7f\n\tListNotes\x12\x1c.grafeas.v1.ListNotesRequest\x1a\x1d.grafeas.v1.ListNotesResponse"5\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/{parent=projects/*}/notes\xda\x41\rparent,filter\x12q\n\nDeleteNote\x12\x1d.grafeas.v1.DeleteNoteRequest\x1a\x16.google.protobuf.Empty",\x82\xd3\xe4\x93\x02\x1f*\x1d/v1/{name=projects/*/notes/*}\xda\x41\x04name\x12\x80\x01\n\nCreateNote\x12\x1d.grafeas.v1.CreateNoteRequest\x1a\x10.grafeas.v1.Note"A\x82\xd3\xe4\x93\x02%"\x1d/v1/{parent=projects/*}/notes:\x04note\xda\x41\x13parent,note_id,note\x12\xa2\x01\n\x10\x42\x61tchCreateNotes\x12#.grafeas.v1.BatchCreateNotesRequest\x1a$.grafeas.v1.BatchCreateNotesResponse"C\x82\xd3\xe4\x93\x02.")/v1/{parent=projects/*}/notes:batchCreate:\x01*\xda\x41\x0cparent,notes\x12\x82\x01\n\nUpdateNote\x12\x1d.grafeas.v1.UpdateNoteRequest\x1a\x10.grafeas.v1.Note"C\x82\xd3\xe4\x93\x02%2\x1d/v1/{name=projects/*/notes/*}:\x04note\xda\x41\x15name,note,update_mask\x12\xa7\x01\n\x13ListNoteOccurrences\x12&.grafeas.v1.ListNoteOccurrencesRequest\x1a\'.grafeas.v1.ListNoteOccurrencesResponse"?\x82\xd3\xe4\x93\x02+\x12)/v1/{name=projects/*/notes/*}/occurrences\xda\x41\x0bname,filter\x1a#\xca\x41 containeranalysis.googleapis.comB\x8a\x01\n\rio.grafeas.v1P\x01ZFgoogle.golang.org/genproto/googleapis/grafeas/grafeas_v1/proto;grafeas\xa2\x02\x03GRA\xea\x41(\n\x12grafeas.io/Project\x12\x12projects/{project}b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_attestation__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_build__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_deployment__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_discovery__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_image__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_upgrade__pb2.DESCRIPTOR,
        grafeas_dot_grafeas__v1_dot_proto_dot_vulnerability__pb2.DESCRIPTOR,
    ],
)


_OCCURRENCE = _descriptor.Descriptor(
    name="Occurrence",
    full_name="grafeas.v1.Occurrence",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.Occurrence.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="resource_uri",
            full_name="grafeas.v1.Occurrence.resource_uri",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="note_name",
            full_name="grafeas.v1.Occurrence.note_name",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="grafeas.v1.Occurrence.kind",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="remediation",
            full_name="grafeas.v1.Occurrence.remediation",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="grafeas.v1.Occurrence.create_time",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="grafeas.v1.Occurrence.update_time",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="vulnerability",
            full_name="grafeas.v1.Occurrence.vulnerability",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="build",
            full_name="grafeas.v1.Occurrence.build",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="grafeas.v1.Occurrence.image",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="package",
            full_name="grafeas.v1.Occurrence.package",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="deployment",
            full_name="grafeas.v1.Occurrence.deployment",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="discovery",
            full_name="grafeas.v1.Occurrence.discovery",
            index=12,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attestation",
            full_name="grafeas.v1.Occurrence.attestation",
            index=13,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="upgrade",
            full_name="grafeas.v1.Occurrence.upgrade",
            index=14,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352AD\n\025grafeas.io/Occurrence\022+projects/{project}/occurrences/{occurrence}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="details",
            full_name="grafeas.v1.Occurrence.details",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=636,
    serialized_end=1364,
)


_NOTE = _descriptor.Descriptor(
    name="Note",
    full_name="grafeas.v1.Note",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.Note.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="short_description",
            full_name="grafeas.v1.Note.short_description",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="long_description",
            full_name="grafeas.v1.Note.long_description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="kind",
            full_name="grafeas.v1.Note.kind",
            index=3,
            number=4,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="related_url",
            full_name="grafeas.v1.Note.related_url",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="expiration_time",
            full_name="grafeas.v1.Note.expiration_time",
            index=5,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="create_time",
            full_name="grafeas.v1.Note.create_time",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_time",
            full_name="grafeas.v1.Note.update_time",
            index=7,
            number=8,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="related_note_names",
            full_name="grafeas.v1.Note.related_note_names",
            index=8,
            number=9,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="vulnerability",
            full_name="grafeas.v1.Note.vulnerability",
            index=9,
            number=10,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="build",
            full_name="grafeas.v1.Note.build",
            index=10,
            number=11,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="image",
            full_name="grafeas.v1.Note.image",
            index=11,
            number=12,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="package",
            full_name="grafeas.v1.Note.package",
            index=12,
            number=13,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="deployment",
            full_name="grafeas.v1.Note.deployment",
            index=13,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="discovery",
            full_name="grafeas.v1.Note.discovery",
            index=14,
            number=15,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="attestation",
            full_name="grafeas.v1.Note.attestation",
            index=15,
            number=16,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="upgrade",
            full_name="grafeas.v1.Note.upgrade",
            index=16,
            number=17,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A2\n\017grafeas.io/Note\022\037projects/{project}/notes/{note}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="type",
            full_name="grafeas.v1.Note.type",
            index=0,
            containing_type=None,
            create_key=_descriptor._internal_create_key,
            fields=[],
        ),
    ],
    serialized_start=1367,
    serialized_end=2137,
)


_GETOCCURRENCEREQUEST = _descriptor.Descriptor(
    name="GetOccurrenceRequest",
    full_name="grafeas.v1.GetOccurrenceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.GetOccurrenceRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\027\n\025grafeas.io/Occurrence",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2139,
    serialized_end=2206,
)


_LISTOCCURRENCESREQUEST = _descriptor.Descriptor(
    name="ListOccurrencesRequest",
    full_name="grafeas.v1.ListOccurrencesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="grafeas.v1.ListOccurrencesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\024\n\022grafeas.io/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="grafeas.v1.ListOccurrencesRequest.filter",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="grafeas.v1.ListOccurrencesRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="grafeas.v1.ListOccurrencesRequest.page_token",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2208,
    serialized_end=2331,
)


_LISTOCCURRENCESRESPONSE = _descriptor.Descriptor(
    name="ListOccurrencesResponse",
    full_name="grafeas.v1.ListOccurrencesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="occurrences",
            full_name="grafeas.v1.ListOccurrencesResponse.occurrences",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="grafeas.v1.ListOccurrencesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2333,
    serialized_end=2428,
)


_DELETEOCCURRENCEREQUEST = _descriptor.Descriptor(
    name="DeleteOccurrenceRequest",
    full_name="grafeas.v1.DeleteOccurrenceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.DeleteOccurrenceRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\027\n\025grafeas.io/Occurrence",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2430,
    serialized_end=2500,
)


_CREATEOCCURRENCEREQUEST = _descriptor.Descriptor(
    name="CreateOccurrenceRequest",
    full_name="grafeas.v1.CreateOccurrenceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="grafeas.v1.CreateOccurrenceRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\024\n\022grafeas.io/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="occurrence",
            full_name="grafeas.v1.CreateOccurrenceRequest.occurrence",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2502,
    serialized_end=2620,
)


_UPDATEOCCURRENCEREQUEST = _descriptor.Descriptor(
    name="UpdateOccurrenceRequest",
    full_name="grafeas.v1.UpdateOccurrenceRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.UpdateOccurrenceRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\027\n\025grafeas.io/Occurrence",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="occurrence",
            full_name="grafeas.v1.UpdateOccurrenceRequest.occurrence",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="grafeas.v1.UpdateOccurrenceRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2623,
    serialized_end=2791,
)


_GETNOTEREQUEST = _descriptor.Descriptor(
    name="GetNoteRequest",
    full_name="grafeas.v1.GetNoteRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.GetNoteRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\021\n\017grafeas.io/Note",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2793,
    serialized_end=2848,
)


_GETOCCURRENCENOTEREQUEST = _descriptor.Descriptor(
    name="GetOccurrenceNoteRequest",
    full_name="grafeas.v1.GetOccurrenceNoteRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.GetOccurrenceNoteRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\027\n\025grafeas.io/Occurrence",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2850,
    serialized_end=2921,
)


_LISTNOTESREQUEST = _descriptor.Descriptor(
    name="ListNotesRequest",
    full_name="grafeas.v1.ListNotesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="grafeas.v1.ListNotesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\024\n\022grafeas.io/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="grafeas.v1.ListNotesRequest.filter",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="grafeas.v1.ListNotesRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="grafeas.v1.ListNotesRequest.page_token",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2923,
    serialized_end=3040,
)


_LISTNOTESRESPONSE = _descriptor.Descriptor(
    name="ListNotesResponse",
    full_name="grafeas.v1.ListNotesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="notes",
            full_name="grafeas.v1.ListNotesResponse.notes",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="grafeas.v1.ListNotesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3042,
    serialized_end=3119,
)


_DELETENOTEREQUEST = _descriptor.Descriptor(
    name="DeleteNoteRequest",
    full_name="grafeas.v1.DeleteNoteRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.DeleteNoteRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\021\n\017grafeas.io/Note",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3121,
    serialized_end=3179,
)


_CREATENOTEREQUEST = _descriptor.Descriptor(
    name="CreateNoteRequest",
    full_name="grafeas.v1.CreateNoteRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="grafeas.v1.CreateNoteRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\024\n\022grafeas.io/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="note_id",
            full_name="grafeas.v1.CreateNoteRequest.note_id",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="note",
            full_name="grafeas.v1.CreateNoteRequest.note",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3181,
    serialized_end=3303,
)


_UPDATENOTEREQUEST = _descriptor.Descriptor(
    name="UpdateNoteRequest",
    full_name="grafeas.v1.UpdateNoteRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.UpdateNoteRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\021\n\017grafeas.io/Note",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="note",
            full_name="grafeas.v1.UpdateNoteRequest.note",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="grafeas.v1.UpdateNoteRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3306,
    serialized_end=3450,
)


_LISTNOTEOCCURRENCESREQUEST = _descriptor.Descriptor(
    name="ListNoteOccurrencesRequest",
    full_name="grafeas.v1.ListNoteOccurrencesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="grafeas.v1.ListNoteOccurrencesRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\021\n\017grafeas.io/Note",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="grafeas.v1.ListNoteOccurrencesRequest.filter",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="grafeas.v1.ListNoteOccurrencesRequest.page_size",
            index=2,
            number=3,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="grafeas.v1.ListNoteOccurrencesRequest.page_token",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3452,
    serialized_end=3574,
)


_LISTNOTEOCCURRENCESRESPONSE = _descriptor.Descriptor(
    name="ListNoteOccurrencesResponse",
    full_name="grafeas.v1.ListNoteOccurrencesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="occurrences",
            full_name="grafeas.v1.ListNoteOccurrencesResponse.occurrences",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="grafeas.v1.ListNoteOccurrencesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3576,
    serialized_end=3675,
)


_BATCHCREATENOTESREQUEST_NOTESENTRY = _descriptor.Descriptor(
    name="NotesEntry",
    full_name="grafeas.v1.BatchCreateNotesRequest.NotesEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="grafeas.v1.BatchCreateNotesRequest.NotesEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="grafeas.v1.BatchCreateNotesRequest.NotesEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"8\001",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3817,
    serialized_end=3879,
)

_BATCHCREATENOTESREQUEST = _descriptor.Descriptor(
    name="BatchCreateNotesRequest",
    full_name="grafeas.v1.BatchCreateNotesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="grafeas.v1.BatchCreateNotesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\024\n\022grafeas.io/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="notes",
            full_name="grafeas.v1.BatchCreateNotesRequest.notes",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[_BATCHCREATENOTESREQUEST_NOTESENTRY,],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3678,
    serialized_end=3879,
)


_BATCHCREATENOTESRESPONSE = _descriptor.Descriptor(
    name="BatchCreateNotesResponse",
    full_name="grafeas.v1.BatchCreateNotesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="notes",
            full_name="grafeas.v1.BatchCreateNotesResponse.notes",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3881,
    serialized_end=3940,
)


_BATCHCREATEOCCURRENCESREQUEST = _descriptor.Descriptor(
    name="BatchCreateOccurrencesRequest",
    full_name="grafeas.v1.BatchCreateOccurrencesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="grafeas.v1.BatchCreateOccurrencesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A\024\n\022grafeas.io/Project",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.FieldDescriptor(
            name="occurrences",
            full_name="grafeas.v1.BatchCreateOccurrencesRequest.occurrences",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3942,
    serialized_end=4067,
)


_BATCHCREATEOCCURRENCESRESPONSE = _descriptor.Descriptor(
    name="BatchCreateOccurrencesResponse",
    full_name="grafeas.v1.BatchCreateOccurrencesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    create_key=_descriptor._internal_create_key,
    fields=[
        _descriptor.FieldDescriptor(
            name="occurrences",
            full_name="grafeas.v1.BatchCreateOccurrencesResponse.occurrences",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
            create_key=_descriptor._internal_create_key,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=4069,
    serialized_end=4146,
)

_OCCURRENCE.fields_by_name[
    "kind"
].enum_type = grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2._NOTEKIND
_OCCURRENCE.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OCCURRENCE.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_OCCURRENCE.fields_by_name[
    "vulnerability"
].message_type = (
    grafeas_dot_grafeas__v1_dot_proto_dot_vulnerability__pb2._VULNERABILITYOCCURRENCE
)
_OCCURRENCE.fields_by_name[
    "build"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_build__pb2._BUILDOCCURRENCE
_OCCURRENCE.fields_by_name[
    "image"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_image__pb2._IMAGEOCCURRENCE
_OCCURRENCE.fields_by_name[
    "package"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2._PACKAGEOCCURRENCE
_OCCURRENCE.fields_by_name[
    "deployment"
].message_type = (
    grafeas_dot_grafeas__v1_dot_proto_dot_deployment__pb2._DEPLOYMENTOCCURRENCE
)
_OCCURRENCE.fields_by_name[
    "discovery"
].message_type = (
    grafeas_dot_grafeas__v1_dot_proto_dot_discovery__pb2._DISCOVERYOCCURRENCE
)
_OCCURRENCE.fields_by_name[
    "attestation"
].message_type = (
    grafeas_dot_grafeas__v1_dot_proto_dot_attestation__pb2._ATTESTATIONOCCURRENCE
)
_OCCURRENCE.fields_by_name[
    "upgrade"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_upgrade__pb2._UPGRADEOCCURRENCE
_OCCURRENCE.oneofs_by_name["details"].fields.append(
    _OCCURRENCE.fields_by_name["vulnerability"]
)
_OCCURRENCE.fields_by_name[
    "vulnerability"
].containing_oneof = _OCCURRENCE.oneofs_by_name["details"]
_OCCURRENCE.oneofs_by_name["details"].fields.append(_OCCURRENCE.fields_by_name["build"])
_OCCURRENCE.fields_by_name["build"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_OCCURRENCE.oneofs_by_name["details"].fields.append(_OCCURRENCE.fields_by_name["image"])
_OCCURRENCE.fields_by_name["image"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_OCCURRENCE.oneofs_by_name["details"].fields.append(
    _OCCURRENCE.fields_by_name["package"]
)
_OCCURRENCE.fields_by_name["package"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_OCCURRENCE.oneofs_by_name["details"].fields.append(
    _OCCURRENCE.fields_by_name["deployment"]
)
_OCCURRENCE.fields_by_name["deployment"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_OCCURRENCE.oneofs_by_name["details"].fields.append(
    _OCCURRENCE.fields_by_name["discovery"]
)
_OCCURRENCE.fields_by_name["discovery"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_OCCURRENCE.oneofs_by_name["details"].fields.append(
    _OCCURRENCE.fields_by_name["attestation"]
)
_OCCURRENCE.fields_by_name["attestation"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_OCCURRENCE.oneofs_by_name["details"].fields.append(
    _OCCURRENCE.fields_by_name["upgrade"]
)
_OCCURRENCE.fields_by_name["upgrade"].containing_oneof = _OCCURRENCE.oneofs_by_name[
    "details"
]
_NOTE.fields_by_name[
    "kind"
].enum_type = grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2._NOTEKIND
_NOTE.fields_by_name[
    "related_url"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_common__pb2._RELATEDURL
_NOTE.fields_by_name[
    "expiration_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NOTE.fields_by_name[
    "create_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NOTE.fields_by_name[
    "update_time"
].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_NOTE.fields_by_name[
    "vulnerability"
].message_type = (
    grafeas_dot_grafeas__v1_dot_proto_dot_vulnerability__pb2._VULNERABILITYNOTE
)
_NOTE.fields_by_name[
    "build"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_build__pb2._BUILDNOTE
_NOTE.fields_by_name[
    "image"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_image__pb2._IMAGENOTE
_NOTE.fields_by_name[
    "package"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_package__pb2._PACKAGENOTE
_NOTE.fields_by_name[
    "deployment"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_deployment__pb2._DEPLOYMENTNOTE
_NOTE.fields_by_name[
    "discovery"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_discovery__pb2._DISCOVERYNOTE
_NOTE.fields_by_name[
    "attestation"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_attestation__pb2._ATTESTATIONNOTE
_NOTE.fields_by_name[
    "upgrade"
].message_type = grafeas_dot_grafeas__v1_dot_proto_dot_upgrade__pb2._UPGRADENOTE
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["vulnerability"])
_NOTE.fields_by_name["vulnerability"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["build"])
_NOTE.fields_by_name["build"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["image"])
_NOTE.fields_by_name["image"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["package"])
_NOTE.fields_by_name["package"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["deployment"])
_NOTE.fields_by_name["deployment"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["discovery"])
_NOTE.fields_by_name["discovery"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["attestation"])
_NOTE.fields_by_name["attestation"].containing_oneof = _NOTE.oneofs_by_name["type"]
_NOTE.oneofs_by_name["type"].fields.append(_NOTE.fields_by_name["upgrade"])
_NOTE.fields_by_name["upgrade"].containing_oneof = _NOTE.oneofs_by_name["type"]
_LISTOCCURRENCESRESPONSE.fields_by_name["occurrences"].message_type = _OCCURRENCE
_CREATEOCCURRENCEREQUEST.fields_by_name["occurrence"].message_type = _OCCURRENCE
_UPDATEOCCURRENCEREQUEST.fields_by_name["occurrence"].message_type = _OCCURRENCE
_UPDATEOCCURRENCEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTNOTESRESPONSE.fields_by_name["notes"].message_type = _NOTE
_CREATENOTEREQUEST.fields_by_name["note"].message_type = _NOTE
_UPDATENOTEREQUEST.fields_by_name["note"].message_type = _NOTE
_UPDATENOTEREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTNOTEOCCURRENCESRESPONSE.fields_by_name["occurrences"].message_type = _OCCURRENCE
_BATCHCREATENOTESREQUEST_NOTESENTRY.fields_by_name["value"].message_type = _NOTE
_BATCHCREATENOTESREQUEST_NOTESENTRY.containing_type = _BATCHCREATENOTESREQUEST
_BATCHCREATENOTESREQUEST.fields_by_name[
    "notes"
].message_type = _BATCHCREATENOTESREQUEST_NOTESENTRY
_BATCHCREATENOTESRESPONSE.fields_by_name["notes"].message_type = _NOTE
_BATCHCREATEOCCURRENCESREQUEST.fields_by_name["occurrences"].message_type = _OCCURRENCE
_BATCHCREATEOCCURRENCESRESPONSE.fields_by_name["occurrences"].message_type = _OCCURRENCE
DESCRIPTOR.message_types_by_name["Occurrence"] = _OCCURRENCE
DESCRIPTOR.message_types_by_name["Note"] = _NOTE
DESCRIPTOR.message_types_by_name["GetOccurrenceRequest"] = _GETOCCURRENCEREQUEST
DESCRIPTOR.message_types_by_name["ListOccurrencesRequest"] = _LISTOCCURRENCESREQUEST
DESCRIPTOR.message_types_by_name["ListOccurrencesResponse"] = _LISTOCCURRENCESRESPONSE
DESCRIPTOR.message_types_by_name["DeleteOccurrenceRequest"] = _DELETEOCCURRENCEREQUEST
DESCRIPTOR.message_types_by_name["CreateOccurrenceRequest"] = _CREATEOCCURRENCEREQUEST
DESCRIPTOR.message_types_by_name["UpdateOccurrenceRequest"] = _UPDATEOCCURRENCEREQUEST
DESCRIPTOR.message_types_by_name["GetNoteRequest"] = _GETNOTEREQUEST
DESCRIPTOR.message_types_by_name["GetOccurrenceNoteRequest"] = _GETOCCURRENCENOTEREQUEST
DESCRIPTOR.message_types_by_name["ListNotesRequest"] = _LISTNOTESREQUEST
DESCRIPTOR.message_types_by_name["ListNotesResponse"] = _LISTNOTESRESPONSE
DESCRIPTOR.message_types_by_name["DeleteNoteRequest"] = _DELETENOTEREQUEST
DESCRIPTOR.message_types_by_name["CreateNoteRequest"] = _CREATENOTEREQUEST
DESCRIPTOR.message_types_by_name["UpdateNoteRequest"] = _UPDATENOTEREQUEST
DESCRIPTOR.message_types_by_name[
    "ListNoteOccurrencesRequest"
] = _LISTNOTEOCCURRENCESREQUEST
DESCRIPTOR.message_types_by_name[
    "ListNoteOccurrencesResponse"
] = _LISTNOTEOCCURRENCESRESPONSE
DESCRIPTOR.message_types_by_name["BatchCreateNotesRequest"] = _BATCHCREATENOTESREQUEST
DESCRIPTOR.message_types_by_name["BatchCreateNotesResponse"] = _BATCHCREATENOTESRESPONSE
DESCRIPTOR.message_types_by_name[
    "BatchCreateOccurrencesRequest"
] = _BATCHCREATEOCCURRENCESREQUEST
DESCRIPTOR.message_types_by_name[
    "BatchCreateOccurrencesResponse"
] = _BATCHCREATEOCCURRENCESRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Occurrence = _reflection.GeneratedProtocolMessageType(
    "Occurrence",
    (_message.Message,),
    {
        "DESCRIPTOR": _OCCURRENCE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """An instance of an analysis type that has been found on a resource.
  
  Attributes:
      name:
          Output only. The name of the occurrence in the form of
          ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
      resource_uri:
          Required. Immutable. A URI that represents the resource for
          which the occurrence applies. For example,
          ``https://gcr.io/project/image@sha256:123abc`` for a Docker
          image.
      note_name:
          Required. Immutable. The analysis note associated with this
          occurrence, in the form of
          ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``. This field can be
          used as a filter in list requests.
      kind:
          Output only. This explicitly denotes which of the occurrence
          details are specified. This field can be used as a filter in
          list requests.
      remediation:
          A description of actions that can be taken to remedy the note.
      create_time:
          Output only. The time this occurrence was created.
      update_time:
          Output only. The time this occurrence was last updated.
      details:
          Required. Immutable. Describes the details of the note kind
          found on this resource.
      vulnerability:
          Describes a security vulnerability.
      build:
          Describes a verifiable build.
      image:
          Describes how this resource derives from the basis in the
          associated note.
      package:
          Describes the installation of a package on the linked
          resource.
      deployment:
          Describes the deployment of an artifact on a runtime.
      discovery:
          Describes when a resource was discovered.
      attestation:
          Describes an attestation of an artifact.
      upgrade:
          Describes an available package upgrade on the linked resource.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Occurrence)
    },
)
_sym_db.RegisterMessage(Occurrence)

Note = _reflection.GeneratedProtocolMessageType(
    "Note",
    (_message.Message,),
    {
        "DESCRIPTOR": _NOTE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """A type of analysis that can be done for a resource.
  
  Attributes:
      name:
          Output only. The name of the note in the form of
          ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
      short_description:
          A one sentence description of this note.
      long_description:
          A detailed description of this note.
      kind:
          Output only. The type of analysis. This field can be used as a
          filter in list requests.
      related_url:
          URLs associated with this note.
      expiration_time:
          Time of expiration for this note. Empty if note does not
          expire.
      create_time:
          Output only. The time this note was created. This field can be
          used as a filter in list requests.
      update_time:
          Output only. The time this note was last updated. This field
          can be used as a filter in list requests.
      related_note_names:
          Other notes related to this note.
      type:
          Required. Immutable. The type of analysis this note
          represents.
      vulnerability:
          A note describing a package vulnerability.
      build:
          A note describing build provenance for a verifiable build.
      image:
          A note describing a base image.
      package:
          A note describing a package hosted by various package
          managers.
      deployment:
          A note describing something that can be deployed.
      discovery:
          A note describing the initial analysis of a resource.
      attestation:
          A note describing an attestation role.
      upgrade:
          A note describing available package upgrades.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.Note)
    },
)
_sym_db.RegisterMessage(Note)

GetOccurrenceRequest = _reflection.GeneratedProtocolMessageType(
    "GetOccurrenceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETOCCURRENCEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to get an occurrence.
  
  Attributes:
      name:
          The name of the occurrence in the form of
          ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.GetOccurrenceRequest)
    },
)
_sym_db.RegisterMessage(GetOccurrenceRequest)

ListOccurrencesRequest = _reflection.GeneratedProtocolMessageType(
    "ListOccurrencesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTOCCURRENCESREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to list occurrences.
  
  Attributes:
      parent:
          The name of the project to list occurrences for in the form of
          ``projects/[PROJECT_ID]``.
      filter:
          The filter expression.
      page_size:
          Number of occurrences to return in the list. Must be positive.
          Max allowed page size is 1000. If not specified, page size
          defaults to 20.
      page_token:
          Token to provide to skip to a particular spot in the list.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ListOccurrencesRequest)
    },
)
_sym_db.RegisterMessage(ListOccurrencesRequest)

ListOccurrencesResponse = _reflection.GeneratedProtocolMessageType(
    "ListOccurrencesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTOCCURRENCESRESPONSE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Response for listing occurrences.
  
  Attributes:
      occurrences:
          The occurrences requested.
      next_page_token:
          The next pagination token in the list response. It should be
          used as ``page_token`` for the following request. An empty
          value means no more results.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ListOccurrencesResponse)
    },
)
_sym_db.RegisterMessage(ListOccurrencesResponse)

DeleteOccurrenceRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteOccurrenceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEOCCURRENCEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to delete an occurrence.
  
  Attributes:
      name:
          The name of the occurrence in the form of
          ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.DeleteOccurrenceRequest)
    },
)
_sym_db.RegisterMessage(DeleteOccurrenceRequest)

CreateOccurrenceRequest = _reflection.GeneratedProtocolMessageType(
    "CreateOccurrenceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEOCCURRENCEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to create a new occurrence.
  
  Attributes:
      parent:
          The name of the project in the form of
          ``projects/[PROJECT_ID]``, under which the occurrence is to be
          created.
      occurrence:
          The occurrence to create.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.CreateOccurrenceRequest)
    },
)
_sym_db.RegisterMessage(CreateOccurrenceRequest)

UpdateOccurrenceRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateOccurrenceRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEOCCURRENCEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to update an occurrence.
  
  Attributes:
      name:
          The name of the occurrence in the form of
          ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
      occurrence:
          The updated occurrence.
      update_mask:
          The fields to update.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.UpdateOccurrenceRequest)
    },
)
_sym_db.RegisterMessage(UpdateOccurrenceRequest)

GetNoteRequest = _reflection.GeneratedProtocolMessageType(
    "GetNoteRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETNOTEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to get a note.
  
  Attributes:
      name:
          The name of the note in the form of
          ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.GetNoteRequest)
    },
)
_sym_db.RegisterMessage(GetNoteRequest)

GetOccurrenceNoteRequest = _reflection.GeneratedProtocolMessageType(
    "GetOccurrenceNoteRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETOCCURRENCENOTEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to get the note to which the specified occurrence is attached.
  
  Attributes:
      name:
          The name of the occurrence in the form of
          ``projects/[PROJECT_ID]/occurrences/[OCCURRENCE_ID]``.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.GetOccurrenceNoteRequest)
    },
)
_sym_db.RegisterMessage(GetOccurrenceNoteRequest)

ListNotesRequest = _reflection.GeneratedProtocolMessageType(
    "ListNotesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTNOTESREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to list notes.
  
  Attributes:
      parent:
          The name of the project to list notes for in the form of
          ``projects/[PROJECT_ID]``.
      filter:
          The filter expression.
      page_size:
          Number of notes to return in the list. Must be positive. Max
          allowed page size is 1000. If not specified, page size
          defaults to 20.
      page_token:
          Token to provide to skip to a particular spot in the list.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ListNotesRequest)
    },
)
_sym_db.RegisterMessage(ListNotesRequest)

ListNotesResponse = _reflection.GeneratedProtocolMessageType(
    "ListNotesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTNOTESRESPONSE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Response for listing notes.
  
  Attributes:
      notes:
          The notes requested.
      next_page_token:
          The next pagination token in the list response. It should be
          used as ``page_token`` for the following request. An empty
          value means no more results.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ListNotesResponse)
    },
)
_sym_db.RegisterMessage(ListNotesResponse)

DeleteNoteRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteNoteRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETENOTEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to delete a note.
  
  Attributes:
      name:
          The name of the note in the form of
          ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.DeleteNoteRequest)
    },
)
_sym_db.RegisterMessage(DeleteNoteRequest)

CreateNoteRequest = _reflection.GeneratedProtocolMessageType(
    "CreateNoteRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATENOTEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to create a new note.
  
  Attributes:
      parent:
          The name of the project in the form of
          ``projects/[PROJECT_ID]``, under which the note is to be
          created.
      note_id:
          The ID to use for this note.
      note:
          The note to create.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.CreateNoteRequest)
    },
)
_sym_db.RegisterMessage(CreateNoteRequest)

UpdateNoteRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateNoteRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATENOTEREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to update a note.
  
  Attributes:
      name:
          The name of the note in the form of
          ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
      note:
          The updated note.
      update_mask:
          The fields to update.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.UpdateNoteRequest)
    },
)
_sym_db.RegisterMessage(UpdateNoteRequest)

ListNoteOccurrencesRequest = _reflection.GeneratedProtocolMessageType(
    "ListNoteOccurrencesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTNOTEOCCURRENCESREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to list occurrences for a note.
  
  Attributes:
      name:
          The name of the note to list occurrences for in the form of
          ``projects/[PROVIDER_ID]/notes/[NOTE_ID]``.
      filter:
          The filter expression.
      page_size:
          Number of occurrences to return in the list.
      page_token:
          Token to provide to skip to a particular spot in the list.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ListNoteOccurrencesRequest)
    },
)
_sym_db.RegisterMessage(ListNoteOccurrencesRequest)

ListNoteOccurrencesResponse = _reflection.GeneratedProtocolMessageType(
    "ListNoteOccurrencesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTNOTEOCCURRENCESRESPONSE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Response for listing occurrences for a note.
  
  Attributes:
      occurrences:
          The occurrences attached to the specified note.
      next_page_token:
          Token to provide to skip to a particular spot in the list.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.ListNoteOccurrencesResponse)
    },
)
_sym_db.RegisterMessage(ListNoteOccurrencesResponse)

BatchCreateNotesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchCreateNotesRequest",
    (_message.Message,),
    {
        "NotesEntry": _reflection.GeneratedProtocolMessageType(
            "NotesEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _BATCHCREATENOTESREQUEST_NOTESENTRY,
                "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2"
                # @@protoc_insertion_point(class_scope:grafeas.v1.BatchCreateNotesRequest.NotesEntry)
            },
        ),
        "DESCRIPTOR": _BATCHCREATENOTESREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to create notes in batch.
  
  Attributes:
      parent:
          The name of the project in the form of
          ``projects/[PROJECT_ID]``, under which the notes are to be
          created.
      notes:
          The notes to create. Max allowed length is 1000.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BatchCreateNotesRequest)
    },
)
_sym_db.RegisterMessage(BatchCreateNotesRequest)
_sym_db.RegisterMessage(BatchCreateNotesRequest.NotesEntry)

BatchCreateNotesResponse = _reflection.GeneratedProtocolMessageType(
    "BatchCreateNotesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHCREATENOTESRESPONSE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Response for creating notes in batch.
  
  Attributes:
      notes:
          The notes that were created.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BatchCreateNotesResponse)
    },
)
_sym_db.RegisterMessage(BatchCreateNotesResponse)

BatchCreateOccurrencesRequest = _reflection.GeneratedProtocolMessageType(
    "BatchCreateOccurrencesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHCREATEOCCURRENCESREQUEST,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Request to create occurrences in batch.
  
  Attributes:
      parent:
          The name of the project in the form of
          ``projects/[PROJECT_ID]``, under which the occurrences are to
          be created.
      occurrences:
          The occurrences to create. Max allowed length is 1000.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BatchCreateOccurrencesRequest)
    },
)
_sym_db.RegisterMessage(BatchCreateOccurrencesRequest)

BatchCreateOccurrencesResponse = _reflection.GeneratedProtocolMessageType(
    "BatchCreateOccurrencesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _BATCHCREATEOCCURRENCESRESPONSE,
        "__module__": "grafeas.grafeas_v1.proto.grafeas_pb2",
        "__doc__": """Response for creating occurrences in batch.
  
  Attributes:
      occurrences:
          The occurrences that were created.
  """,
        # @@protoc_insertion_point(class_scope:grafeas.v1.BatchCreateOccurrencesResponse)
    },
)
_sym_db.RegisterMessage(BatchCreateOccurrencesResponse)


DESCRIPTOR._options = None
_OCCURRENCE._options = None
_NOTE._options = None
_GETOCCURRENCEREQUEST.fields_by_name["name"]._options = None
_LISTOCCURRENCESREQUEST.fields_by_name["parent"]._options = None
_DELETEOCCURRENCEREQUEST.fields_by_name["name"]._options = None
_CREATEOCCURRENCEREQUEST.fields_by_name["parent"]._options = None
_CREATEOCCURRENCEREQUEST.fields_by_name["occurrence"]._options = None
_UPDATEOCCURRENCEREQUEST.fields_by_name["name"]._options = None
_UPDATEOCCURRENCEREQUEST.fields_by_name["occurrence"]._options = None
_GETNOTEREQUEST.fields_by_name["name"]._options = None
_GETOCCURRENCENOTEREQUEST.fields_by_name["name"]._options = None
_LISTNOTESREQUEST.fields_by_name["parent"]._options = None
_DELETENOTEREQUEST.fields_by_name["name"]._options = None
_CREATENOTEREQUEST.fields_by_name["parent"]._options = None
_CREATENOTEREQUEST.fields_by_name["note_id"]._options = None
_CREATENOTEREQUEST.fields_by_name["note"]._options = None
_UPDATENOTEREQUEST.fields_by_name["name"]._options = None
_UPDATENOTEREQUEST.fields_by_name["note"]._options = None
_LISTNOTEOCCURRENCESREQUEST.fields_by_name["name"]._options = None
_BATCHCREATENOTESREQUEST_NOTESENTRY._options = None
_BATCHCREATENOTESREQUEST.fields_by_name["parent"]._options = None
_BATCHCREATENOTESREQUEST.fields_by_name["notes"]._options = None
_BATCHCREATEOCCURRENCESREQUEST.fields_by_name["parent"]._options = None
_BATCHCREATEOCCURRENCESREQUEST.fields_by_name["occurrences"]._options = None

_GRAFEAS = _descriptor.ServiceDescriptor(
    name="Grafeas",
    full_name="grafeas.v1.Grafeas",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A containeranalysis.googleapis.com",
    create_key=_descriptor._internal_create_key,
    serialized_start=4149,
    serialized_end=6215,
    methods=[
        _descriptor.MethodDescriptor(
            name="GetOccurrence",
            full_name="grafeas.v1.Grafeas.GetOccurrence",
            index=0,
            containing_service=None,
            input_type=_GETOCCURRENCEREQUEST,
            output_type=_OCCURRENCE,
            serialized_options=b"\202\323\344\223\002%\022#/v1/{name=projects/*/occurrences/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListOccurrences",
            full_name="grafeas.v1.Grafeas.ListOccurrences",
            index=1,
            containing_service=None,
            input_type=_LISTOCCURRENCESREQUEST,
            output_type=_LISTOCCURRENCESRESPONSE,
            serialized_options=b"\202\323\344\223\002%\022#/v1/{parent=projects/*}/occurrences\332A\rparent,filter",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteOccurrence",
            full_name="grafeas.v1.Grafeas.DeleteOccurrence",
            index=2,
            containing_service=None,
            input_type=_DELETEOCCURRENCEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002%*#/v1/{name=projects/*/occurrences/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateOccurrence",
            full_name="grafeas.v1.Grafeas.CreateOccurrence",
            index=3,
            containing_service=None,
            input_type=_CREATEOCCURRENCEREQUEST,
            output_type=_OCCURRENCE,
            serialized_options=b'\202\323\344\223\0021"#/v1/{parent=projects/*}/occurrences:\noccurrence\332A\021parent,occurrence',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchCreateOccurrences",
            full_name="grafeas.v1.Grafeas.BatchCreateOccurrences",
            index=4,
            containing_service=None,
            input_type=_BATCHCREATEOCCURRENCESREQUEST,
            output_type=_BATCHCREATEOCCURRENCESRESPONSE,
            serialized_options=b'\202\323\344\223\0024"//v1/{parent=projects/*}/occurrences:batchCreate:\001*\332A\022parent,occurrences',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateOccurrence",
            full_name="grafeas.v1.Grafeas.UpdateOccurrence",
            index=5,
            containing_service=None,
            input_type=_UPDATEOCCURRENCEREQUEST,
            output_type=_OCCURRENCE,
            serialized_options=b"\202\323\344\223\00212#/v1/{name=projects/*/occurrences/*}:\noccurrence\332A\033name,occurrence,update_mask",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetOccurrenceNote",
            full_name="grafeas.v1.Grafeas.GetOccurrenceNote",
            index=6,
            containing_service=None,
            input_type=_GETOCCURRENCENOTEREQUEST,
            output_type=_NOTE,
            serialized_options=b"\202\323\344\223\002+\022)/v1/{name=projects/*/occurrences/*}/notes\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="GetNote",
            full_name="grafeas.v1.Grafeas.GetNote",
            index=7,
            containing_service=None,
            input_type=_GETNOTEREQUEST,
            output_type=_NOTE,
            serialized_options=b"\202\323\344\223\002\037\022\035/v1/{name=projects/*/notes/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListNotes",
            full_name="grafeas.v1.Grafeas.ListNotes",
            index=8,
            containing_service=None,
            input_type=_LISTNOTESREQUEST,
            output_type=_LISTNOTESRESPONSE,
            serialized_options=b"\202\323\344\223\002\037\022\035/v1/{parent=projects/*}/notes\332A\rparent,filter",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="DeleteNote",
            full_name="grafeas.v1.Grafeas.DeleteNote",
            index=9,
            containing_service=None,
            input_type=_DELETENOTEREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002\037*\035/v1/{name=projects/*/notes/*}\332A\004name",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="CreateNote",
            full_name="grafeas.v1.Grafeas.CreateNote",
            index=10,
            containing_service=None,
            input_type=_CREATENOTEREQUEST,
            output_type=_NOTE,
            serialized_options=b'\202\323\344\223\002%"\035/v1/{parent=projects/*}/notes:\004note\332A\023parent,note_id,note',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="BatchCreateNotes",
            full_name="grafeas.v1.Grafeas.BatchCreateNotes",
            index=11,
            containing_service=None,
            input_type=_BATCHCREATENOTESREQUEST,
            output_type=_BATCHCREATENOTESRESPONSE,
            serialized_options=b'\202\323\344\223\002.")/v1/{parent=projects/*}/notes:batchCreate:\001*\332A\014parent,notes',
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="UpdateNote",
            full_name="grafeas.v1.Grafeas.UpdateNote",
            index=12,
            containing_service=None,
            input_type=_UPDATENOTEREQUEST,
            output_type=_NOTE,
            serialized_options=b"\202\323\344\223\002%2\035/v1/{name=projects/*/notes/*}:\004note\332A\025name,note,update_mask",
            create_key=_descriptor._internal_create_key,
        ),
        _descriptor.MethodDescriptor(
            name="ListNoteOccurrences",
            full_name="grafeas.v1.Grafeas.ListNoteOccurrences",
            index=13,
            containing_service=None,
            input_type=_LISTNOTEOCCURRENCESREQUEST,
            output_type=_LISTNOTEOCCURRENCESRESPONSE,
            serialized_options=b"\202\323\344\223\002+\022)/v1/{name=projects/*/notes/*}/occurrences\332A\013name,filter",
            create_key=_descriptor._internal_create_key,
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_GRAFEAS)

DESCRIPTOR.services_by_name["Grafeas"] = _GRAFEAS

# @@protoc_insertion_point(module_scope)
